"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = ContentPlugin;

var _loadFile = require("./loadFile");

var _loadDirectory = require("./loadDirectory");

const UnsupportedError = new Error('Unsupported configuration for babel-plugin-content-transformer');

function ContentPlugin({
  types
}) {
  return {
    pre() {
      this.watchMap = new Map(); // Map nodes to their watched files so we can replace them
    },

    post() {},

    watchFiles(files) {},

    visitor: {
      ImportDeclaration: {
        enter(path, state) {
          const opts = state.opts;

          if (opts.transformers) {
            for (const t of opts.transformers) {
              if (!t.file) {
                throw UnsupportedError;
              }

              if (path.node && path.node.source && t.file.test(path.node.source.value)) {
                (0, _loadFile.loadFile)(types, path, state, t);
                break;
              }
            }
          }

          if (opts.content) {
            for (const c of opts.content) {
              if (!c.dir) {
                throw UnsupportedError;
              }

              if (path.node && path.node.source && c.dir.test(path.node.source.value)) {
                (0, _loadDirectory.loadDirectory)(types, path, state, c);
                break;
              }
            }
          }

          if (!(opts.transformers || opts.content)) {
            throw UnsupportedError;
          }
        },

        exit(path, state) {
          console.log('exit', path);
        }

      }
    }
  };
}