"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.loadFile = loadFile;

var fs = _interopRequireWildcard(require("fs"));

var _utils = require("./utils");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function loadFile(t, p, state, opts) {
  if (p.node.specifiers.length > 1) {
    throw new Error(`Only default imports are supported. Check the import statement for '${loc}' in ${state.file.opts.filename}`);
  }

  const specifier = p.node.specifiers[0];
  const id = specifier.local.name; // Function that transforms content into an AST node

  let transformer = contents => t.valueToNode(contents);

  if (opts.transform) {
    transformer = contents => {
      return t.valueToNode(opts.transform(contents));
    };
  } else {
    switch (opts.format) {
      case 'yaml':
        const YAML = require('yaml');

        transformer = contents => t.valueToNode(YAML.parse(contents));

        break;

      case 'toml':
        const toml = require('toml');

        transformer = contents => t.valueToNode(toml.parse(contents));

        break;

      default:
        transformer = contents => t.stringLiteral(contents);

    }
  }

  const fullPath = (0, _utils.resolvePath)(p.node.source.value, state.file.opts.filename);
  const fileContents = fs.readFileSync(fullPath, 'utf-8');
  const transformedVal = transformer(fileContents, fullPath);
  p.replaceWith({
    type: 'VariableDeclaration',
    kind: 'const',
    declarations: [t.variableDeclarator(t.identifier(id), transformedVal)],
    leadingComments: [{
      type: 'CommentBlock',
      value: `babel-content-loader '${p.node.source.value}'`
    }]
  });
}